@@ -9,7 +9,7 @@ Overview:
 The algorithm solves "hybrid" least squares linear programming (LS-LP) problems
 with the help of the Moore-Penrose inverse (pseudoinverse), calculated using
 singular value decomposition (SVD), with emphasis on estimation of non-typical
-constrained OLS (cOLS), Relationship Matrix (RM) [1], and custom (user-defined)
+constrained OLS (cOLS), Transaction Matrix (TM) [1], and custom (user-defined)
 cases. The pseudoinverse offers a unique solution and may be the best linear
 unbiased estimator (BLUE) for a group of problems under certain conditions [2].
 
@@ -17,7 +17,7 @@ Example of a non-typical cOLS problem:
 - Estimate the trend and the cyclical component of a country's GDP given
   the textbook or any other definition of its peaks, troughs, and saddles.
 
-Example of an RM problem:
+Example of an TM problem:
 - Estimate the input-output table or a matrix of trade / investment / etc.,
   the technical coefficients or (country) shares of which are unknown.
 
@@ -28,7 +28,7 @@ coefficients for CONSTRAINTS and for SLACK VARIABLES (the upper part) as well
 as for MODEL (the lower part) as illustrated in Figure 1. Each part of `a` can
 be omitted to accommodate a special case:
 - cOLS problems require no case-specific CONSTRAINTS;
-- RM problems require case-specific CONSTRAINTS, no problem CONSTRAINTS, and
+- TM problems require case-specific CONSTRAINTS, no problem CONSTRAINTS, and
   an optional MODEL;
 - SLACK VARIABLES are non-zero only for inequality constraints and are omitted
   if problems don't include any;
@@ -50,32 +50,32 @@ of numpy.linalg.lstsq(). To check if `a` is within computational limits, its
 
 - (2 * N) x (K + K*    )    cOLS without slack variables;
 - (2 * N) x (K + K* + 1)    cOLS with slack variables;
-- (M * N) x (M * N)         RM without slack variables;
-- (M * N) x (M * N + 1)     RM with slack variables;
+- (M * N) x (M * N)         TM without slack variables;
+- (M * N) x (M * N + 1)     TM with slack variables;
 - M x N                     custom without slack variables;
 - M x (N + 1)               custom with slack variables;
 
 where, in cOLS problems, K is the number of independent variables in the model
 (including the constant), K* (K* \not \in K) is the number of extra variables
-in CONSTRAINTS, and N is the number of observations; in RM problems, M and N
-are the dimensions of the relationship matrix; and in custom cases, M and N or
+in CONSTRAINTS, and N is the number of observations; in TM problems, M and N
+are the dimensions of the transaction matrix; and in custom cases, M and N or
 M x (N + 1) are the dimensions of `a` (fully user-defined).
 
 Parameters:
 –––––––––––
     # LS-LP type and input
     lp        : str or unicode, optional
-                'cOLS' (Constrained OLS), 'RM' (Relationship Matrix), or
+                'cOLS' (Constrained OLS), 'TM' (Transaction Matrix), or
                 'custom' (user-defined case).
     lhs       : sequence of array_like
                 Left-hand side of the problem (NB 3D iterable for lp='cOLS').
     rhs       : sequence of array_like
-                Right-hand side of the problem (NB row sums first for lp='RM').
+                Right-hand side of the problem (NB row sums first for lp='TM').
     svar      : array_like
                 Slack variables.
     # `a` and estimation
     diag      : bool, optional
-                Diagonal of M x N (NB for lp='RM').
+                Diagonal of M x N (NB for lp='TM').
     rcond     : float, optional
                 Cut-off ratio for small singular values of a. For the purposes
                 of rank determination, singular values are treated as zero if
@@ -105,12 +105,12 @@ Raises:
 
 Notes:
 ––––––
-[1] Relationship Matrix (RM) of size M x N is a formal model of relationships
+[1] Transaction Matrix (TM) of size M x N is a formal model of transactions
     between M and N elements in a system.
     For example,
-    - an input-output table (IOT) is a type of RM where M = N and the elements
+    - an input-output table (IOT) is a type of TM where M = N and the elements
       are industries;
-    - a matrix of trade / investment / etc. is a type of RM where M = N and
+    - a matrix of trade / investment / etc. is a type of TM where M = N and
       the elements are countries or (macro)regions in which diagonal elements
       can, in some cases, all be equal to zero.
 
@@ -132,7 +132,7 @@ def solve(
 ):
     """main function"""
     # Check for errors ------------------------------------------------------- #
-    if lp not in ('cOLS', 'RM', 'custom'):             # LS-LP type
+    if lp not in ('cOLS', 'TM', 'custom'):             # LS-LP type
         raise LPpinvError("Unknown LS-LP problem type")
 
     # Construct `b` and `a` -------------------------------------------------- #
@@ -141,7 +141,7 @@ def solve(
              if lp != 'custom' else np.array(rhs))
         if lp == 'cOLS':                               # LS-LP type: cOLS
             a = np.row_stack([np.vstack(l).T for l in lhs])
-        if lp == 'RM':                                 # LS-LP type: RM
+        if lp == 'TM':                                 # LS-LP type: TM
             r, c = (len(l) for l in rhs[0:2])
             a = np.row_stack([
                 np.kron(np.identity(r), np.ones(c)),   # row sums
@@ -163,22 +163,24 @@ def solve(
                     np.array(svar), np.zeros(b.size - np.array(svar).size)
                 ]) if lp == 'cOLS' else np.array(svar)
             ).T])
-        assert a                                       # check for `a`
+        assert a.size                                  # check for `a`
     except:
         raise LPpinvError("Misspecified LHS, RHS, or SVAR")
 
     # Obtain an SVD-based solution ------------------------------------------- #
     soln = list(np.linalg.lstsq(a, b, rcond))
-    if np.array(svar).size:                        # slack variables
-        if lp == 'cOLS':                           # LS-LP type: cOLS
+    if np.array(svar).size:                            # slack variables
+        if lp == 'cOLS':
             soln[0] = soln[0][0:-1]
-        if lp == 'RM':                             # LS-LP type: RM
-            soln[0] = soln[0][0:r * c].reshape(r, c)
+        if lp == 'TM':
+            soln[0] = soln[0][0:r * c]
+    if lp == 'TM':                                     # LS-LP type: TM
+        soln[0] = soln[0].reshape(r, c)
     soln[2] = a, soln[2]
 
     # Calculate MSE ---------------------------------------------------------- #
     if not np.array(soln[1]).size:
-        if lp == 'RM':                                 # LS-LP type: RM
+        if lp == 'TM':                                 # LS-LP type: TM
             soln[1] = np.array([np.sum(np.square(
                 np.subtract(b, np.concatenate([
                     soln[0].sum(axis=1 - i) for i in range(2)
